@@ -18,6 +18,8 @@ def parse_arguments():
     parser.add_argument('vcf', metavar='<input.vcf>', help='input VCF file')
     parser.add_argument('--groups', metavar='<"GROUP">', nargs='+',
                         help='specify a subset of sample groups')
+    parser.add_argument('--remove-bnd', action='store_true',
+                        help='remove "BND" calls')
     return parser.parse_args()
 
 
